import React, { PropTypes } from 'react';
import PureRenderMixin from 'react-addons-pure-render-mixin';
import { Link } from 'react-router';
import invariant from 'invariant';

import ButtonContent from './ButtonContent';

import isNullOrEmpty from '../../isNullOrEmpty';
import getRootClassName from './utils/getRootClassName';
import { iconShape } from './utils/propTypes';


export default ({
    block,
    displayName,
    uiPropDefaultType = PropTypes.string,
    uiPropDefaultValue = '',
    uiPropGetValue = (ui) => ui
} = {}) => {

    invariant(block !== undefined, 'Missing purebem block.');
    invariant(!isNullOrEmpty(displayName), 'Missing display name.');

    const Content = ButtonContent({ block, displayName: `${displayName}Content` });

    return React.createClass({

        displayName,

        mixins: [PureRenderMixin],

        propTypes: {
            activeUI: PropTypes.string,
            children: PropTypes.node,
            disabled: PropTypes.bool,
            icon: iconShape,
            onClick: PropTypes.func,
            to: PropTypes.oneOfType([PropTypes.object, PropTypes.string]),
            ui: uiPropDefaultType
        },

        getDefaultProps() {
            return {
                activeUI: null,
                children: null,
                disabled: false,
                icon: null,
                onClick: (/* evt */) => {},
                to: '',
                ui: uiPropDefaultValue
            };
        },

        onClick(evt) {
            const { disabled, onClick } = this.props;
            if (disabled) {
                return evt.preventDefault();
            }

            onClick(evt);
        },

        render() {
            const { activeUI, children, disabled, icon, to, ui, ...rest } = this.props;
            return (
                <Link
                    { ...rest }
                    activeClassName={ activeUI !== null ? block({ activeUI }) : null }
                    className={ getRootClassName(block, { children, icon, ui: uiPropGetValue(ui) }, { disabled }) }
                    data-react-router-link={ true }
                    onClick={ this.onClick }
                    tabIndex="0"
                    to={ to }>
                    <Content
                        icon={ icon }>
                        { children }
                    </Content>
                </Link>
            );
        }

    });

};
