import React from 'react';
import ReactDOM from 'react-dom';
import TestUtils from 'react-addons-test-utils';
import purebem from 'purebem';

import Switch from './Switch';


const block = purebem.of('test-switch');
// Used to click the lever. Far from ideal, but at least the tests will fail if the style is refactored.
const leverElement = block('content-lever');

const TestSwitch = Switch({
    block,
    displayName: 'TestSwitch'
});

const clickLever = (checkbox) => {
    const lever = TestUtils.findRenderedDOMComponentWithClass(checkbox, leverElement);
    const node = ReactDOM.findDOMNode(lever);

    TestUtils.Simulate.click(node);
};

const spaceLever = (checkbox) => {
    const lever = TestUtils.findRenderedDOMComponentWithClass(checkbox, leverElement);
    const node = ReactDOM.findDOMNode(lever);

    TestUtils.Simulate.keyDown(node, { which: 32 });
};

describe('Switch', () => {

    it('should be checked when clicked and is unchecked', () => {
        const onChange = jest.fn();

        const checkbox = TestUtils.renderIntoDocument(
            <TestSwitch onChange={ onChange } value={ false } />
        );

        clickLever(checkbox);

        expect(onChange).toHaveBeenCalledWith(true);
    });

    it('should be unchecked when clicked and is checked', () => {
        const onChange = jest.fn();

        const checkbox = TestUtils.renderIntoDocument(
            <TestSwitch onChange={ onChange } value={ true } />
        );

        clickLever(checkbox);

        expect(onChange).toHaveBeenCalledWith(false);
    });

    it('should remain unchecked when disabled and clicked', () => {
        const onChange = jest.fn();

        const checkbox = TestUtils.renderIntoDocument(
            <TestSwitch disabled={ true } onChange={ onChange } value={ false } />
        );

        clickLever(checkbox);

        expect(onChange).not.toHaveBeenCalled();
    });

    it('should remain checked when disabled and clicked', () => {
        const onChange = jest.fn();

        const checkbox = TestUtils.renderIntoDocument(
            <TestSwitch disabled={ true } onChange={ onChange } value={ true } />
        );

        clickLever(checkbox);

        expect(onChange).not.toHaveBeenCalled();
    });

    it('should be checked when using space and is unchecked', () => {
        const onChange = jest.fn();

        const checkbox = TestUtils.renderIntoDocument(
            <TestSwitch onChange={ onChange } value={ false } />
        );

        spaceLever(checkbox);

        expect(onChange).toHaveBeenCalledWith(true);
    });

    it('should be unchecked when using space and is checked', () => {
        const onChange = jest.fn();

        const checkbox = TestUtils.renderIntoDocument(
            <TestSwitch onChange={ onChange } value={ true } />
        );

        spaceLever(checkbox);

        expect(onChange).toHaveBeenCalledWith(false);
    });

    it('should remain unchecked when disabled and using space', () => {
        const onChange = jest.fn();

        const checkbox = TestUtils.renderIntoDocument(
            <TestSwitch disabled={ true } onChange={ onChange } value={ false } />
        );

        spaceLever(checkbox);

        expect(onChange).not.toHaveBeenCalled();
    });

    it('should remain checked when disabled and using space', () => {
        const onChange = jest.fn();

        const checkbox = TestUtils.renderIntoDocument(
            <TestSwitch disabled={ true } onChange={ onChange } value={ true } />
        );

        spaceLever(checkbox);

        expect(onChange).not.toHaveBeenCalled();
    });

});
