import React from 'react';
import ReactDOM from 'react-dom';
import TestUtils from 'react-addons-test-utils';
import purebem from 'purebem';

import DropdownActionOption from './DropdownActionOption';


const TestDropdownActionOption = DropdownActionOption({
    block: purebem.of('test-dropdown'),
    displayName: 'TestDropdownActionOption'
});

describe('TestDropdownActionOption', () => {

    it('should perform action when clicked', () => {
        const onClick = jest.fn();

        const option = TestUtils.renderIntoDocument(
            <TestDropdownActionOption
                onClick={ onClick }
                value="test" />
        );

        const node = ReactDOM.findDOMNode(option);
        TestUtils.Simulate.click(node);

        expect(onClick).toHaveBeenCalledWith('test');
    });

    it('should not perform action when clicked and disabled', () => {
        const handler = jest.fn();

        const option = TestUtils.renderIntoDocument(
            <TestDropdownActionOption
                disabled={ true }
                onClick={ handler }
                value="test" />
        );

        const node = ReactDOM.findDOMNode(option);
        TestUtils.Simulate.click(node);

        expect(handler).not.toHaveBeenCalled();
    });

});
